@@ -27,14 +27,23 @@
 //! ```
 
 #![deny(missing_docs)]
+#![deny(unsafe_code)]
+#![cfg_attr(feature = "platform_independent", forbid(unsafe_code))]
 
-extern crate byteorder;
-#[cfg(feature="rayon")]
+extern crate alloc;
+extern crate core;
+
+#[cfg(feature = "rayon")]
 extern crate rayon;
 
 pub use decoder::{Decoder, ImageInfo, PixelFormat};
 pub use error::{Error, UnsupportedFeature};
+pub use parser::CodingProcess;
 
+use std::io;
+
+#[cfg(not(feature = "platform_independent"))]
+mod arch;
 mod decoder;
 mod error;
 mod huffman;
@@ -43,3 +52,15 @@ mod marker;
 mod parser;
 mod upsampler;
 mod worker;
+
+fn read_u8<R: io::Read>(reader: &mut R) -> io::Result<u8> {
+    let mut buf = [0];
+    reader.read_exact(&mut buf)?;
+    Ok(buf[0])
+}
+
+fn read_u16_from_be<R: io::Read>(reader: &mut R) -> io::Result<u16> {
+    let mut buf = [0, 0];
+    reader.read_exact(&mut buf)?;
+    Ok(u16::from_be_bytes(buf))
+}
